<?PHP
/*
 * AlijaPlugin.class.php - Alija plugin for Stud.IP
 * Copyright (c) 2007  Elmar Ludwig
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 */

// require flexi templates
require_once 'vendor/flexi/flexi.php';

require_once 'lib/classes/Token.class.php';
require_once 'AlijaData.php';

/**
 * Format text for Alija plugin (like formatReady() plus extra syntax
 * to include external content using "[[<url>]]").
 */
function alijaFormatReady ($text)
{
    // formatReady will destroy the special markup if it detects the link,
    // so urlencode() is used here before the text is handed to formatReady().
    $text = preg_replace('/\(:include (.*?):\)/e', "'(:include '.urlencode('\$1').':)'", $text);
    $text = formatReady($text);
    $text = preg_replace('/\(:include (.*?):\)/e', "'(:include '.urldecode('\$1').':)'", $text);
    $text = preg_replace('/\(:include (.*?):\)/e', "file_get_contents('\$1')", $text);

    return $text;
}

/**
 * PHP class for Alija homepage plugin
 */
class AlijaPlugin extends AbstractStudIPHomepagePlugin
{
    var $alija_data;
    var $template_factory;

    function AlijaPlugin ()
    {
        parent::AbstractStudIPHomepagePlugin();

        $this->alija_data = new AlijaData(NULL);
        $this->template_factory = new Flexi_TemplateFactory(dirname(__FILE__).'/templates/');

        $user = $this->getUser();
        $permission = $user->getPermission();

        // this plugin wants its own icon
        $this->setPluginIconName("images/icon.gif");

        // navigation
        $navigation =& new PluginNavigation();
        $navigation->setDisplayname($this->getDisplaytitle());
        $navigation->addLinkParam('action', 'main');

        if ($permission->hasRootPermission())
        {
            $config_nav =& new PluginNavigation();
            $config_nav->setDisplayname(_('Einstellungen'));
            $config_nav->addLinkParam('action', 'config');
            $navigation->addSubmenu($config_nav);
        }

        $this->setNavigation($navigation);
    }

    function initialize ()
    {
        global $HELP_KEYWORD;

        $HELP_KEYWORD = 'Alija';
    }

    function getPluginname ()
    {
        return 'Alija';
    }

    function getDisplaytitle ()
    {
        $title = $this->alija_data->getTitle();

        return $title != '' ? $title : $this->getPluginname();
    }

    function actionShow ()
    {
        $action = $_REQUEST['action'];

        switch ($action)
        {
            case 'config':
                $this->editConfig();
                break;

            default:
                $this->display();
        }
    }

    function display ()
    {
        // ABSOLUTE_URI_STUDIP is not available in 1.2-os1
        if (isset($GLOBALS['ABSOLUTE_URI_STUDIP']))
            $ABSOLUTE_URI_STUDIP = $GLOBALS['ABSOLUTE_URI_STUDIP'];
        else
            $ABSOLUTE_URI_STUDIP = 'http://'.$GLOBALS['EXTERN_SERVER_NAME'];

        // get new token valid for 1 hour
        $user = $this->getUser();
        $token = new Token($user->getUserid(), 3600);

        $external_url = $this->alija_data->getUrl();
        $validate_url = sprintf('%s%s/validate.php?token=%s', $ABSOLUTE_URI_STUDIP,
                                $this->getPluginPath(), $token->get_token());

        $user = $this->getRequestedUser();
        $username = $user->getUsername();
        $content = $this->alija_data->getContent();
        $content = str_replace('%USERNAME%', $username, $content);

        $template = $this->template_factory->open('display');
        $template->set_attribute('alija_format', true);
        $template->set_attribute('content', $content);
        $template->set_attribute('chuser', $this->alija_data->getUser());
        $template->set_attribute('chdate', $this->alija_data->getChangeDate());
        $template->set_attribute('external_url', $external_url);
        $template->set_attribute('validate_url', $validate_url);

        echo $template->render();
    }

    function editConfig ()
    {
        $user = $this->getUser();
        $permission = $user->getPermission();

        if (!$permission->hasRootPermission())
        {
            StudIPTemplateEngine::showErrorMessage(_('Sie besitzen keine Berechtigung, um dieses Plugin zu konfigurieren.'));
            return;
        }

        if (isset($_REQUEST['save']) || isset($_REQUEST['save_x']))
        {
            // remove magic quotes
            $title = stripslashes($_REQUEST['title']);
            $content = stripslashes($_REQUEST['content']);
            $url = stripslashes($_REQUEST['url']);

            $this->alija_data->setTitle($title);
            $this->alija_data->setContent($content);
            $this->alija_data->setURL($url);
            $this->alija_data->setUser($user->getUserid());
            $this->alija_data->store();
        }

        $template = $this->template_factory->open('config');
        $template->set_attribute('title', $this->alija_data->getTitle());
        $template->set_attribute('content', $this->alija_data->getContent());
        $template->set_attribute('url', $this->alija_data->getURL());
        $template->set_attribute('plugin', $this);

        echo $template->render();
    }

    function showOverview ()
    {
        $user = $this->getRequestedUser();
        $username = $user->getUsername();
        $content = $this->alija_data->getContent();
        $content = str_replace('%USERNAME%', $username, $content);

        $template = $this->template_factory->open('overview');
        $template->set_attribute('content', $content);

        echo $template->render();
    }
}
?>
